#!/bin/sh

cat <<EOF
* { box-sizing: border-box; }
body {
  position: relative;
  width: 100%;
  margin: 0; padding: 0;
  padding-top: 2em;
}

input.tab { display: none; }
input.tab + label.tab { display: block; }
input.tab + label.tab::before { content: '\25b8 \00a0'; float: left;}
input.tab:checked + label.tab::before { content: '\25be \00a0'; }
input.tab + label.tab + div.tab { display: none; }
input.tab:checked + label.tab + div.tab { display: block; }

input.color { display: none }
input.color + label{
  display: inline-block;
  width: 1em; height: 1em;
  border: 1px solid black;
}
input.color:checked + label{ border-width: 3px;}
input.color[value="#000"] + label,
input.color[value="#888"] + label { background-color: #888;}
input.color[value="#00A"] + label { background-color: #00F;}
input.color[value="#0A0"] + label { background-color: #0F0;}
input.color[value="#0AA"] + label { background-color: #0FF;}
input.color[value="#A00"] + label { background-color: #F00;}
input.color[value="#A0A"] + label { background-color: #F0F;}
input.color[value="#AA0"] + label { background-color: #FF0;}
input.color[value="#FFF"] + label { background-color: #FFF;}

h1, label.tab, div.tab, fieldset.tab,
div.patient, div.prescription {
  display: block;
  width: 96%;
  margin: 0 2%;
}

div.prescription .insurance{ display: block; margin: .5ex 0 1ex 0; }
div.prescription label.checkbox,
div.prescription label.radio { padding-left: 1.25em; font-size: 1em;}

div.prescription label.checkbox:before,
div.prescription label.radio:before {
  display: inline-block;
  color: #000;
  background-color: #FFF;
  height: 1.375em; width: 1.125em;
  padding: .125em 0 0 .375em;
  margin: 0 .5em .25em -1.25em;
  border: 1px solid #000;
  vertical-align: middle;
  content: ' ';
}
div.prescription label.radio:before { border-radius: .5em;}
div.prescription label.checkbox.checked:before,
div.prescription label.radio.checked:before { content: "\2713";}

div.prescription label[for=prescreviewed] {
  margin-left: 1ex;
  font-weight: bold;
  text-decoration: underline;
  background-color: #FCC;
}
div.prescription label[for=prescreviewed].checked {
  font-weight: normal;
  text-decoration: none;
  background-color: transparent;
}

fieldset.color {
  margin: .5em 2% 0 2%;
  border: none;
  padding: 0;
}
.dotmark {
  max-width: 96%;
  margin: .125em 2%; padding: 0;
  text-align: left;
  border: 1px dotted black;
}
.dotmark.ov {
  position: absolute;
  bottom: 5px; right: 0;
  z-index: 1;
  border: none;
}
@media(min-width: 800px){
  h1, label.tab, div.tab, fieldset.tab,
  div.patient, div.prescription {
    width: 38%;
    margin-right: 0;
  }
  fieldset.color{
    position: fixed;
    max-width: 56%;
    right: 0;
    top: 0em;
  }
  .dotmark {
    position: fixed;
    max-width: 56%;
    max-height: 480px;
    right: 0;
    top: 2em;
  }
  .dotmark.ov {
    position: fixed;
    bottom: auto;
  }
}

h1 {display: none;}

div.patient, div.prescription { margin-top: 1em; }
div.prescription {
  border: 1px solid black;
  background-color: #EEE;
  padding: .125em 1.25ex .5em 1.25ex;
}
div > h2 { margin: 0; border-bottom: 1px solid black; }
div:nth-child(n+2) > a:first-of-type {
  display: block;
  margin: .125em 0 .5em 0;
  text-decoration: none;
}

fieldset.tab,
label.tab {
  font-size: 1.25em;
  font-weight: bold;
  padding: .125em 1ex .25em 1ex;
  color: #FFF;
  background-color: #333;
  margin-top: .125em;
  text-align: right;
  border: none;
}
label.heading {
  background-color: #FFF;
  margin-top: 1em;
  border: 2px solid black;
  border-bottom-width: 1px;
  color: black;
}
label.heading > span {
  text-decoration: underline;
}

fieldset.tab > *,
label > input,
label > span {
  display: inline-block;
  text-align: right;
}
.tab > .no {
  width:  10%; float: left;
  border: solid 1px #FFF;
  background-color: #555;
  border-radius: 2ex;
  padding: 0;
  text-align: center;
}
label.heading > span.no {
  background-color: inherit;
  border: none;
}
.tab > .date      { width: 30%; }
.tab > .therapist { width: 40%; }
.tab > .signature { width: 10%; }
.tab > .signature > button { display: inline-block; margin: 0; }
fieldset.tab > button[type=submit] { width: 5%; text-align: center; margin-left: 5%;}

.signature > button[value=pos],
.signature > button[value=neg] {
  margin-bottom: .25em;
  border: 1px solid black;
  height: 1.5em; width: 1.5em;
  vertical-align: top;
  background-color: #FFF;
  color: #000;
  white-space: nowrap;
}
.signature > input[type=checkbox] {display: none;}
.signature > button[value=neg]::before { padding: 0 1ex 0 .25ex; content: "\2713"; }
.signature > button[value=pos]::before { padding: 0 1ex 0 .25ex; content: "\00a0 \00a0 \00a0"; }

input.tab + label.tab > input.date,
input.tab + label.tab > input.therapist {
  display: none;
}
input.tab:checked + label.tab > input.date,
input.tab:checked + label.tab > input.therapist {
  display: inline;
}
input.tab:checked + label.tab > span.date,
input.tab:checked + label.tab > span.therapist {
  display: none;
}


div.tab {
  border: 2px solid #333;
  border-top-width: 1px;
  margin-top: -1px;
  padding: .25em .5ex;
}
div.tab > fieldset.note {
  border: none;
  margin: 0; padding: 0;
}
div.tab > fieldset.note > textarea {
  display: block;
  width: 95%; height: 8em;
  margin: -8em 0 .5em 1.25em;
  font: normal 1em sans-serif;
}
div.tab > fieldset.note > input.color + label { margin: 0; display: block; }
div.tab > fieldset.note > input.color[value="#888"]:checked ~ textarea { background-color: #AAA; }
div.tab > fieldset.note > input.color[value="#00A"]:checked ~ textarea { background-color: #88F; }
div.tab > fieldset.note > input.color[value="#0A0"]:checked ~ textarea { background-color: #8F8; }
div.tab > fieldset.note > input.color[value="#0AA"]:checked ~ textarea { background-color: #8FF; }
div.tab > fieldset.note > input.color[value="#A00"]:checked ~ textarea { background-color: #F88; }
div.tab > fieldset.note > input.color[value="#A0A"]:checked ~ textarea { background-color: #F8F; }
div.tab > fieldset.note > input.color[value="#AA0"]:checked ~ textarea { background-color: #FF8; }
div.tab > fieldset.note > input.color[value="#FFF"]:checked ~ textarea { background-color: #FFF; }

div.tab > button.delete {float: right; display: inline-block;}
EOF

# vi:set filetype=css:
